<p align="center">
  <a href="https://d3blocks.github.io/d3blocks/pages/html/index.html">
  <img src="https://github.com/d3blocks/d3blocks/blob/main/logo.png" align="center" width="600" /> 
  </a>
</p>


[![Python](https://img.shields.io/pypi/pyversions/d3blocks)](https://img.shields.io/pypi/pyversions/d3blocks)
[![PyPI Version](https://img.shields.io/pypi/v/d3blocks)](https://pypi.org/project/d3blocks/)
[![License](https://img.shields.io/badge/license-GPL3-green.svg)](https://github.com/d3blocks/d3blocks/blob/master/LICENSE)
[![Github Forks](https://img.shields.io/github/forks/d3blocks/d3blocks.svg)](https://github.com/d3blocks/d3blocks/network)
[![GitHub Open Issues](https://img.shields.io/github/issues/d3blocks/d3blocks.svg)](https://github.com/d3blocks/d3blocks/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![Downloads](https://pepy.tech/badge/d3blocks/month)](https://pepy.tech/project/d3blocks/month)
[![Downloads](https://pepy.tech/badge/d3blocks)](https://pepy.tech/project/d3blocks)
[![Sphinx](https://img.shields.io/badge/Sphinx-Docs-blue)](https://d3blocks.github.io/d3blocks/)


-------------------------------------------------------------------------
<p align="center">
  <a href="https://d3blocks.github.io/d3blocks/pages/html/index.html">
  <img src="https://github.com/d3blocks/d3blocks/blob/main/docs/figs/summary.png" width="600" />
  </a>
</p>

-------------------------------------------------------------------------

#### Installation (Pypi)
```bash
pip install d3blocks     # Normal installation
pip install -U d3blocks  # Force update
```

#### Installation (clone)
```bash
git clone https://github.com/d3blocks/d3blocks.git
cd d3blocks
pip install -U .
```  

#### Import d3blocks package
```python
from d3blocks import d3blocks
# Initialize
d3 = D3Blocks()
```

-------------------------------------------------------------------------
### [Supported charts](https://d3blocks.github.io/d3blocks/)

D3Blocks builts on the graphics of d3 javascript (d3js) to create the most visually attractive and useful charts with only a few lines of Python code!
The [documentation pages](https://d3blocks.github.io/d3blocks/) contains detailed information about the working of the blocks with many examples. 


|  Block                                                                             |    Function                  |
|------------------------------------------------------------------------------------|------------------------------|
| [D3graph (network)](https://d3blocks.github.io/d3blocks/pages/html/d3graph.html)   | ``` d3.d3graph() ```         |
| [Sankey](https://d3blocks.github.io/d3blocks/pages/html/Sankey.html)               | ``` d3.sankey()  ```         |
| [Movingbubbles](https://d3blocks.github.io/d3blocks/pages/html/MovingBubbles.html) | ``` d3.movingbubbles()  ```  |
| [Heatmap](https://d3blocks.github.io/d3blocks/pages/html/Heatmap.html)             | ``` d3.heatmap()  ```        |
| [Chord diagram](https://d3blocks.github.io/d3blocks/pages/html/Chord.html)         | ``` d3.chord()  ```          |
| [Timeseries](https://d3blocks.github.io/d3blocks/pages/html/Timeseries.html)       | ``` d3.timeseries()  ```     |
| [Scatter](https://d3blocks.github.io/d3blocks/pages/html/Scatter.html)             | ``` d3.scatter()  ```        |
| [Image slider](https://d3blocks.github.io/d3blocks/pages/html/Imageslider.html)    | ``` d3.imageslider()  ```    |
| [Violin plot](https://d3blocks.github.io/d3blocks/pages/html/Violin.html)          | ``` d3.violin()  ```         |
| [Particles](https://d3blocks.github.io/d3blocks/pages/html/Particles.html)         | ``` d3.particles()  ```      |
|                                                                                    |                              |

-------------------------------------------------------------------------



#### References
* [bl.ocks](https://bl.ocks.org/)
* [observablehq](https://observablehq.com/top)
